**************************************************************************************************************************************************
*********************************************************** BOOK ANALYSIS ************************************************************************
********************************************************** REPLICATION CODE  *********************************************************************
**************************************************** CHAPTER 9 (DEMOCRATIZATION) *****************************************************************
**************************************************************************************************************************************************

clear
use "/Users/brancati/Documents/Book Project II/Analysis/Analysis-Data/BookProject_DataYear.dta"

****************************
***DESCRIPTIVE STATISTICS***
****************************

bysort size: tab transition
bysort size: tab reform 
bysort size: tab democratization

tab protest if transition == 1
tab protest if reform  == 1
tab protest if democratization == 1

bysort democratization: tabstat sizeCAP if size != 0
bysort transition: tabstat sizeCAP if size != 0
bysort reform: tabstat sizeCAP if size != 0
 *recode reform . = 1 if country == "Egypt" & year == 2011

foreach X of varlist ruralonly urbanonly urbanrural {
bysort democratization: tab `X' if protest == 1
bysort transition: tab `X' if protest == 1
bysort reform: tab `X' if protest == 1
}

**************
***ANALYSIS***
**************
*************************************************************************************************************
**PROTESTS W/CONTROLS FOR REGIME CHARACTERISTICS  (AND REPRESSIVE CAPACITY OF STATE, REGIME TYPE/DEMOCRACY) *
*************************************************************************************************************

*****************
***TRANSITIONS***
*****************

****************
*** Model 9.1 **
****************

logit transition transition_lag size lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
for num 0/5: prvalue, x(size=X)

***ROBUSTNESS**
* alternative form of ordinal measure of size
tab size, gen(indicator) 
drop if indicator6 == 1  (due to collinearity)
logit transition transition_lag indicator2 indicator3 indicator4 indicator5 lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
test indicator1 indicator2 indicator3 indicator4 indicator5
clear

*exclude borderline cases
logit transition transition_lag size lnwdi_GDPcap_lag coup_ALL  pollag1 physint_lag decade00_2011 if borderline !=1, cluster(id)

*particpants per capita
logit transition transition_lag sizeCAP lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag decade00_2011, cluster(id)

*alternative measure of democracy, regime type. 
logit transition transition_lag size lnwdi_GDPcap_lag coup_ALL gwf_party gwf_military gwf_monarchy gwf_personal gwf_warlord physint_lag decade00_2011, cluster(id)
 test gwf_party gwf_military gwf_monarchy gwf_personal 

*alternative measures of force
logit transition transition_lag size coup_ALL lnwdi_GDPcap_lag pollag1 mil_xpnd_gdp_lag wdi_population_total_lag decade00_2011, cluster(id)
logit transition transition_lag size coup_ALL lnwdi_GDPcap_lag pollag1 forcesCAP_lag wdi_population_total_lag decade00_2011, cluster(id)
logit transition transition_lag size lnwdi_GDPcap_lag coup_ALL pollag1 repress nvrepress decade00_2011 if protest==1, cluster(id)
  test repress nvrepress
  
*Exclude cases in which the TRANSITION was clearly not causal although the protests occurred before the transition. 
 drop if country == "Cameroon" & year == 1992
 drop if country == "Guyana" & year == 1992
 drop if country == "Ghana" & year == 1992
 drop if country == "Guatemala" & year == 1995
 drop if country == "Haiti" & year == 2005
 drop if country == "Iraq" & year == 2010
 drop if country == "Kyrgyz Republic" & year == 2010
 drop if country == "Kyrgyz Republic" & year == 2011
 drop if country == "Malaysia" & year == 2007
 drop if country == "Mali" & year == 1991
 drop if country == "Niger" & year == 2010
 drop if country == "Thailand" & year == 2006
 drop if country == "Thailand" & year == 2007
 drop if country == "Peru" & year == 2000
logit transition transition_lag protest lnwdi_GDPcap_lag coup_ALL  pollag1 physint_lag decade00_2011, cluster(id)
clear 



*************** 
** MODEL 9.2 **
***************

logit transition transition_lag size ruralonly urbanonly urbanrural lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
  test urbanonly urbanrural  (rural only is dropped) 
  
* urban/rural restricted to protests only
logit transition transition_lag size ruralonly urbanonly urbanrural lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011 if protest !=0, cluster(id)


 
*************
***REFORMS***
*************

*************** 
** MODEL 9.3 **
***************


logit reform reform_lag size lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
for num 0/5: prvalue, x(size=X)

**ROBUSTNESS**
*democratization, rather than reforms
logit democratization democratization_lag size lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)

* alternative form of ordinal measure of size
tab size, gen(indicator) 
drop if indicator6 == 1  (due to collinearity)
logit reform reform_lag indicator2 indicator3 indicator4 indicator5 lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
test  indicator2 indicator3 indicator4 indicator5
clear

*participants per capita
logit reform reform_lag sizeCAP lnwdi_GDPcap_lag coup_ALL  pollag1 physint_lag decade00_2011, cluster(id)
logit democratization democratization_lag sizeCAP lnwdi_GDPcap_lag coup_ALL  pollag1 physint_lag decade00_2011, cluster(id)


*exclude borderline cases
logit reform reform_lag size lnwdi_GDPcap_lag coup_ALL  pollag1 physint_lag decade00_2011 if borderline !=1, cluster(id)

*alternative measure of democracy, regime type
logit reform reform_lag size lnwdi_GDPcap_lag coup_ALL gwf_party gwf_military gwf_monarchy gwf_personal gwf_warlord physint_lag decade00_2011, cluster(id)
 test gwf_party gwf_military gwf_monarchy gwf_personal
 
*alternative measure of force 
logit reform reform_lag size coup_ALL lnwdi_GDPcap_lag pollag1 mil_xpnd_gdp_lag wdi_population_total_lag decade00_2011, cluster(id)
logit reform reform_lag size coup_ALL lnwdi_GDPcap_lag pollag1 forcesCAP_lag wdi_population_total_lag decade00_2011, cluster(id)
logit reform reform_lag size lnwdi_GDPcap_lag coup_ALL pollag1 repress nvrepress decade00_2011 if protest==1, cluster(id)

*Drop cases were REFORM was clearly not causal although they occurred before the reform. 
 drop if country == "Azerbaijan" & year == 1991
 drop if country == "Burkina Faso" & year == 1991
 drop if country == "Croatia" & year == 2005
 drop if country == "Egypt" & year == 2010
 drop if country == "Gabon" & year == 2009
 drop if country == "Guinea" & year == 2010
 drop if country == "Kuwait" & year == 1992
 drop if country == "Niger" & year == 2009
 drop if country == "Yugoslavia" & year == 1996
 drop if country == "Yugoslavia" & year == 1997
logit reform reform_lag size lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
clear


*************** 
** MODEL 9.4 **
***************
logit reform reform_lag size ruralonly urbanonly urbanrural lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
 test urbanonly urbanrural

* urban/rural restricted to protests only
logit reform reform_lag size ruralonly urbanonly urbanrural lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011 if size !=0, cluster(id)


********************************
* OTHER PROTEST CHARACTERISTICS*
********************************

*****************
***TRANSITIONS***
*****************

*************** 
** MODEL 9.5 **
***************
logit transition transition_lag demand_fraud demand_vote  demand_compete demand_renew demand_respect lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
 test demand_fraud demand_compete demand_respect demand_renew
 *noprotest, demand_other dropped and demand_vote are dropped from the models.

*logit transition transition_lag noprotest demand_fraud demand_compete demand_renew demand_respect lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011 if protest == 1, cluster(id)
  test demand_fraud demand_compete demand_respect demand_renew
  
*logit transition transition_lag cprotest noncprotest lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
  test cprotest noncprotest

*logit transition transition_lag cprotest lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011 if protest == 1, cluster(id)

 
 
*************** 
** MODEL 9.6 **
*************** 
logit transition transition_lag vprotest nonvprotest lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
 test vprotest nonvprotest
 *logit transition transition_lag noprotest nonvprotest lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
 *logit transition transition_lag nonvprotest lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011 if protest==1, cluster(id)


**ADDITIONAL MODELS* 
logit transition transition_lag cprotest noncprotest lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
 test cprotest noncprotest
 *logit transition transition_lag noncprotest lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011 if protest==1, cluster(id)
  


*************
***REFORMS***
*************

*************** 
** MODEL 9.7 **
***************
logit reform reform_lag demand_fraud demand_vote demand_compete demand_respect demand_renew  demand_other lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
  test demand_fraud  demand_compete demand_respect 
 *noprotest, demand_other, demand_vote and demand_renew dropped. 
 
*logit reform reform_lag reform reform_lag noprotest demand_fraud demand_vote demand_compete demand_respect demand_renew demand_other lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011 if protest == 1, cluster(id)
 *nprotest, demand_other and demand_respect dropped
  test demand_fraud demand_compete  
 
*************** 
** MODEL 9.8 **
***************
logit reform reform_lag vprotest nonvprotest lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
 test noprotest nonvprotest
  *logit reform reform_lag noprotest nonvprotest lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
  *logit reform reform_lag vprotest nonvprotest lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011 if protest==1, cluster(id)



**ADDITIONAL MODELS* 
logit reform reform_lag cprotest noncprotest lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
 test cprotest noncprotest
 *logit reform reform_lag noprotest noncprotest  lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011 if protest==1, cluster(id)

logit reform reform_lag rallies lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011, cluster(id)
 prvalue, x(rallies=1)
 prvalue, x(rallies=30)

***********************
* ECONOMIC INEQUALITY *
***********************
*1=inequality; 0=equality. (smaller numbers, lower inequality)



***************
**TRANSITIONS**
***************

*************** 
** MODEL 9.9 **
***************

logit transition transition_lag size SWIID_gini_net_lag lnwdi_GDPcap_lag coup_ALL pollag1  physint_lag wdi_population_total_lag decade00_2011, cluster(id)


**************** 
** MODEL 9.11 **
****************

gen size_gini = size*SWIID_gini_net_lag
logit transition transition_lag size SWIID_gini_net_lag size_gini lnwdi_GDPcap_lag coup_ALL pollag1  physint_lag wdi_population_total_lag decade00_2011, cluster(id)
  test size SWIID_gini_net_lag size_gini 


*************
***REFORMS***
*************

**************** 
** MODEL 9.10 **
****************

logit reform reform_lag size SWIID_gini_net_lag lnwdi_GDPcap_lag coup_ALL pollag1  physint_lag wdi_population_total_lag decade00_2011, cluster(id)

**************** 
** MODEL 9.12 **
****************
gen size_gini = size*SWIID_gini_net_lag
logit reform reform_lag size SWIID_gini_net_lag size_gini lnwdi_GDPcap_lag coup_ALL pollag1  physint_lag wdi_population_total_lag decade00_2011, cluster(id)
  test size SWIID_gini_net_lag size_gini 

         
********************
**CAPITAL MOBILITY**
********************

***************
**TRANSITIONS**
***************

******************************
**GDP per CAPITA (not shown)**
******************************
gen size_GDPcap = lnwdi_GDPcap_lag*size
logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag size_GDPcap wdi_population_total_lag decade00_2011, cluster(id)
 test size lnwdi_GDPcap_lag size_GDPcap 
 prvalue, x(lnwdi_GDPcap_lag=5.5 size=1 size_GDPcap=5.5)
 prvalue, x(lnwdi_GDPcap_lag=7.8 size=1 size_GDPcap=7.8)

***************************
** MODEL 9.13, EDUCATION **
***************************

logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_education2_lag wdi_population_total_lag decade00_2011, cluster(id)
 *logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_education_lag wdi_population_total_lag decade00_2011, cluster(id)

gen size_EDU2 = wdi_education2_lag*size
logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_education2_lag size_EDU2 wdi_population_total_lag decade00_2011, cluster(id)
 test size wdi_education2_lag size_EDU2

***************************** 
** MODEL 9.14, AGRICULTURE **
*****************************

logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag WDI_agriculture_lag wdi_population_total_lag decade00_2011, cluster(id)
 *logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag agactive_lag wdi_population_total_lag decade00_2011, cluster(id)

gen size_AGR = WDI_agriculture_lag*size
logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag WDI_agriculture_lag size_AGR wdi_population_total_lag decade00_2011, cluster(id)
 test size WDI_agriculture_lag size_AGR
 prvalue, x(WDI_agriculture_lag=0)
 prvalue, x(WDI_agriculture_lag=30)
 prvalue, x(WDI_agriculture_lag=50)

*logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag agactive_lag wdi_population_total_lag decade00_2011, cluster(id)

*gen size_AGACTIVE = agactive_lag*size
*logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag agactive_lag size_AGACTIVE  wdi_population_total_lag decade00_2011, cluster(id)
*test size agactive_lag size_AGACTIVE
*prvalue, x(agactive_lag=0)
*prvalue, x(agactive_lag=30)
*prvalue, x(agactive_lag=50)



***************************** 
** MODEL 9.15, FUEL EXPORTS**
*****************************

logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag WDI_FuelExp_lag  wdi_population_total_lag decade00_2011, cluster(id)
 prvalue, x(WDI_FuelExp_lag=5 size=1)
 prvalue, x(WDI_FuelExp_lag=10 size=1)
  *logit transition transition_lag size USEIA_gas_lag USEIA_oil_lag pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_population_total_lag decade00_2011, cluster(id)
  *logit transition transition_lag size USEIA_gas_lag pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag  wdi_population_total_lag decade00_2011, cluster(id)
  *logit transition transition_lag size USEIA_oil_lag pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_population_total_lag decade00_2011, cluster(id)

gen size_FUEL = WDI_FuelExp_lag*size
logit transition transition_lag size WDI_FuelExp_lag size_FUEL pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_population_total_lag decade00_2011, cluster(id)
  test size size_FUEL WDI_FuelExp_lag
    prvalue, x(WDI_FuelExp_lag=5 size=2 size_FUEL=10)
    prvalue, x(WDI_FuelExp_lag=10 size=2 size_FUEL=20)

logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag USEIA_gas_lag  wdi_population_total_lag decade00_2011, cluster(id)
gen size_GAS = size*USEIA_gas_lag
logit transition transition_lag size USEIA_gas_lag size_GAS pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag  wdi_population_total_lag decade00_2011, cluster(id)
  test size size_GAS USEIA_gas_lag 
  prvalue, x(USEIA_gas_lag=0 size=1)
  prvalue, x(USEIA_gas_lag=200 size=1)

gen size_OIL = size*USEIA_oil_lag
logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag USEIA_oil_lag wdi_population_total_lag decade00_2011, cluster(id)
 logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag size_OIL USEIA_oil_lag, cluster(id)
  test size size_OIL USEIA_oil_lag 

*************************** 
** MODEL 9.16, H-H INDEX **
***************************
**Hirsch-Herfindhal Index Economic Concentration** (not significant)
* 0=homogeneous market between the exporters or importers to 1=very concentrated.

logit transition transition_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag UNCTAD_concIndex_lag wdi_population_total_lag decade00_2011, cluster(id)
  prvalue, x(UNCTAD_concIndex_lag=0 size=1)
  prvalue, x(UNCTAD_concIndex_lag=15 size=1)
  prvalue, x(UNCTAD_concIndex_lag=30 size=1)
  prvalue, x(UNCTAD_concIndex_lag=45 size=1)
 
gen size_concIndex = UNCTAD_concIndex_lag*size
logit transition transition_lag size UNCTAD_concIndex_lag size_concIndex pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag  wdi_population_total_lag decade00_2011, cluster(id)
 test size size_concIndex UNCTAD_concIndex_lag
 



***********
**REFORMS**
***********
******************************
**GDP per CAPITA (not shown)**
******************************
gen size_GDPcap = lnwdi_GDPcap_lag*size
logit reform reform_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag size_GDPcap wdi_population_total_lag decade00_2011, cluster(id)
 test size lnwdi_GDPcap_lag size_GDPcap 
 prvalue, x(lnwdi_GDPcap_lag=5.5 size=1 size_GDPcap=5.5)
 prvalue, x(lnwdi_GDPcap_lag=7.8 size=1 size_GDPcap=7.8)
 
***************************
** MODEL 9.17, EDUCATION **
***************************

logit reform reform_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_la wdi_education2_lag wdi_population_total_lag decade00_2011, cluster(id)
 *logit reform reform_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_education_lag wdi_population_total_lag decade00_2011, cluster(id)

gen size_EDU2 = size*wdi_education2_lag
logit reform reform_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_education2_lag size_EDU2 wdi_population_total_lag decade00_2011, cluster(id)
 test size wdi_education2_lag size_EDU2

***************************** 
** MODEL 9.18, AGRICULTURE **
*****************************
 
logit reform reform_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag WDI_agriculture_lag wdi_population_total_lag decade00_2011, cluster(id)
 *logit reform reform_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag agactive_lag wdi_population_total_lag decade00_2011, cluster(id)
 
logit reform reform_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag WDI_agriculture_lag size_AGR wdi_population_total_lag decade00_2011, cluster(id)
 test size WDI_agriculture_lag size_AGR 
 
 

****************************** 
** MODEL 9.19, FUEL EXPORTS  *
******************************
logit reform reform_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag WDI_FuelExp_lag  wdi_population_total_lag decade00_2011, cluster(id)
  *logit reform reform_lag size USEIA_gas_lag USEIA_oil_lag pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_population_total_lag decade00_2011, cluster(id)
  *logit reform reform_lag size USEIA_gas_lag pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_population_total_lag decade00_2011, cluster(id)
  *logit reform reform_lag size USEIA_oil_lag pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_population_total_lag decade00_2011, cluster(id)

gen size_GAS = size*USEIA_gas_lag
logit reform reform_lag size USEIA_gas_lag size_GAS pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_population_total_lag decade00_2011, cluster(id)
  test size size_GAS USEIA_gas_lag 
  prvalue, x(USEIA_gas_lag=0 size=1)
  prvalue, x(USEIA_gas_lag=200 size=1)

gen size_OIL = size*USEIA_oil_lag
logit reform reform_lag size USEIA_gas_lag size_OIL pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag wdi_population_total_lag decade00_2011, cluster(id)
  test size size_OIL USEIA_oil_lag 

*************************** 
** MODEL 9.20, H-H INDEX **
***************************
*Market Concentration} (UNCTAD_concIndex). Herfindahl-Hirschmann Index ranging from 0=homogeneous market between the exporters or importers to 1=very concentrated. 


logit reform reform_lag size pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag  UNCTAD_concIndex_lag wdi_population_total_lag decade00_2011, cluster(id)

logit reform reform_lag size UNCTAD_concIndex_lag size_concIndex pollag1 coup_ALL physint_lag lnwdi_GDPcap_lag  wdi_population_total_lag decade00_2011, cluster(id)
 test size size_concIndex UNCTAD_concIndex_lag
  prvalue, x(UNCTAD_concIndex_lag=0 protest=1)
  prvalue, x(UNCTAD_concIndex_lag=15 protest=1)
  prvalue, x(UNCTAD_concIndex_lag=30 protest=1)
  prvalue, x(UNCTAD_concIndex_lag=45 protest=1)

*************************************************************************************************************
*  MATCHING (R-CODE AND STATA), IN-TEXT (NOT TABLES) 
*************************************************************************************************************

update.packages()
install.packages("MatchIt")
library(MatchIt)
library(foreign)

#####################
## FULL MATCHING. ###
#####################

## STATA-CODE TO CREATE MATCHED SAMPLE##
use "/Users/brancati/Documents/Book Project II/Analysis/Analysis-Data/BookProject_DataYear.dta"
keep if (protest != . & lnwdi_GDPcap_lag != . & wdi_GDPcapGrowth_lag  != . & wdi_infl_lag != . & ILO_unemploy_lag != . & eyear != . & pollag1 != . & physint_lag != .)
keep country year protest lnwdi_GDPcap_lag wdi_GDPcapGrowth_lag wdi_infl_lag ILO_unemploy_lag eyear pollag1 physint_lag
save "/Users/brancati/Documents/Book Project II/Analysis/Analysis-Data/matching/BookProject_DataYearNOMISSING.dta", replace

## R-CODE TO CREATE WEIGHTS ###
matchdataSTATA <- read.dta("/Users/brancati/Documents/Book Project II/Analysis/Analysis-Data/matching/BookProject_DataYearNOMISSING.dta", convert.factors=FALSE, convert.underscore=TRUE)
m.out.full0 <- matchit(protest~ lnwdi.GDPcap.lag+wdi.GDPcapGrowth.lag+wdi.infl.lag+ILO.unemploy.lag+eyear+pollag1+physint.lag, data = matchdataSTATA, method = "full")
m.data.full0 <- match.data(m.out.full0)
write.csv(m.data.full0, "/Users/brancati/Documents/Book Project II/Analysis/Analysis-Data/matching/BookProject_DataYearMATCH.csv")

## ANALYZE IN STATA##
clear
insheet using "/Users/brancati/Documents/Book Project II/Analysis/Analysis-Data/matching/BookProject_DataYearMATCH.csv"
merge country year using "/Users/brancati/Documents/Book Project II/Analysis/Analysis-Data/BookProject_DataYear.dta", sort

##TEST BALANCE: COMPARISON OF MEANS BETWEEN TREATED AND CONTROL GROUPS##
for var lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag: ttest X, by (protest)
for var lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag: gen Xwt = X*weight
for var lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag: ttest Xwt, by (protest)


##LOGISTIC REGRESSION WITH WEIGHTS FROM FULL MATCHING##
logit transition transition_lag size lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011 [pweight=weights], cluster(id)

logit reform reform_lag size lnwdi_GDPcap_lag coup_ALL pollag1 physint_lag wdi_population_total_lag decade00_2011 [pweight=weights], cluster(id)

